<div style="text-align: center;">
  <img src="ablina.svg" alt="ablina" style="width: 100%; height: auto;" />
</div>

## Documentation

https://ablina.readthedocs.io/en/latest

## Installation

Ablina can be installed using pip:

    pip install ablina

or by directly cloning the git repository:

    git clone https://github.com/daniyal1249/ablina.git

and running the following in the cloned repo:

    pip install .
